{% extends 'base.html' %}
{% load i18n %}

{% block content %}
<p>{% trans "You have successfully registered in our site. Now you should activate your account. Check email please." %}</p>
{% endblock %}
