{% extends "base.html" %}
{% load i18n %}

{% block content %}
<h1>{% trans "Authorization" %}</h1>
<p>{% trans "You should login to gain access to all site features. If you have not account" %} <a href="{% url registration_register %}">{% trans "register" %}</a> {% trans "please" %}</p>
<form class="login-form" method="post">
    <div class="wide">{{ form.as_p }}</div>
    <p><input type="submit" value="{% trans "login" %}" /></p>
    <input type="hidden" name="next" value="{{ next }}" />
</form>
<a href="{% url auth_password_reset %}">{% trans "I forgot password" %}</a>

{% endblock %}
