{% extends 'base.html' %}
{% load i18n %}

{% block content %}
<h1>{% trans "New password" %}</h1>
<form method="post" action="{% url auth_password_change %}">
    <div class="wide">{{ form.as_p }}</div>
    <p><input type="submit" value="{% trans "Save" %}" /></p>
</form>

{% endblock %}
