{% extends 'base.html' %}
{% load i18n %}

{% block content %}
{% if user.is_authenticated %}
{% trans "Password has been changed." %}
{% else %}
{% blocktrans %}Password has been changed. You can now <a href="{{ login_url }}">log on</a> site.{% endblocktrans %}
{% endif %}
{% endblock %}
