{% extends "base.html" %}
{% load i18n %}

{% block content %}
<h1>{% trans "Registration" %}</h1>
<form method="post">
    <div class="wide">{{ form.as_p }}</div>
    <p><input type="submit" value="{% trans "Continue" %}" /></p>
</form>

{% endblock %}
