{% extends 'base.html' %}
{% load i18n %}

{% block content %}
<h1>{% trans "Welcome" %}</h1>
<p>
{% trans "Congratulations! You have successfully complete the registration on our site." %}
</p>
{% endblock %}
